@@ -222,7 +222,7 @@ class ProjectPluginEnum(Enum):
     LOAD_LIMITS = 'load_limits'
     LOAD_PLAN = 'load_plan'
     MAGIC_ANALYTIC = 'magic_analytic'
-    MCHS = 'mchs'
+    ACCOUNTING_MCHS = 'accounting_mchs'
     NOMER_DOGOVORA = 'nomer_dogovora'
     NOVOSIB_SERVICE_PF_ACT = 'novosib_service_pf_act'
     OPERATIONS_JOURNAL_04_ACCOUNTS_ANALYTICS = 'operations_journal_04_accounts_analytics'
@@ -459,7 +459,7 @@ class ProjectPluginEnum(Enum):
                     cls.LOAD_LIMITS,
                     cls.LOAD_PLAN,
                     cls.MAGIC_ANALYTIC,
-                    cls.MCHS,
+                    cls.ACCOUNTING_MCHS,
                     cls.NOMER_DOGOVORA,
                     cls.NOVOSIB_SERVICE_PF_ACT,
                     cls.OSS,
@@ -627,7 +627,7 @@ class ProjectPluginEnum(Enum):
             cls.MAGIC_ANALYTIC: (
                 cls.ACCOUNTING,
             ),
-            cls.MCHS: (
+            cls.ACCOUNTING_MCHS: (
                 cls.ACCOUNTING,
             ),
             cls.NOMER_DOGOVORA: (
